/************************************************************************
*
*                          ML2DEMO1.C
*
*           Shows the handling of a Multi-LAB/2 board from a PC
*           with Windows NT
*                                                                      
*					      version      : see history
*							creation 	 : 05.01.96
*							last change  : see history
*							author       : M.Hcker
*
* 		(c) by SORCUS Computer GmbH Heidelberg 1996
*************************************************************************/

/************************************************************************
*
*	software requirements:
*       To make an EXE-file you have to link NML2BIB.LIB and ML2ERRD.C.  
*		  To run the application the NMLXBIB.DLL must be in the actual
*       directory or in the systems path
*
*  hints:
*		- this program is tested with MSVC V.4.1 but it should run with
* 			  other compilers that make 32-bit-code	
*
*     - to compile this example you have to build a 'console application' 
*       because of the use of 'printf'.
*  
*     - the operating system for the Multi-LAB/2 card (ML2-1x.xxR) 
*       must be in the given path (see variable 'osx'). If this file
*       is not found (at runtime) please change the path at  
*       definition of the 'osx'-variable.
*
*************************************************************************/

/************************************************************************
*  history:
*   	1.B. 04.08.96 (MIH):
*        - MSVC 4.1
*        - ml2_reset: changing OsX to ml2-*.*
*   	1.A. 05.01.96 (MIH):
*        - creation of the file
*************************************************************************/

#include <conio.h>
#include <stdio.h>
#include <dos.h>
#include <stdlib.h>
#include <windows.h>

#include "ml2bib.h"

#define BLINK_COUNT 20						// number of LED switching
#define MS_WAITING  100					   // delay between switching


void errorhandler(void);
void waitmillisec(unsigned long msec);


void main(void)
{
	unsigned int	retval;
	unsigned int	w;
	char			   errorstr[80];
	char			   *osx;
	byte           errorclass, errorcode;


   printf("\n***********************************************************\n");
   printf("             DEMO1: makes the LED blinking\n");
   printf("***********************************************************\n");

   /* ml2_bib_startup: this procedure must be called before all other
      ml2_xxx procedures because of library initialisation.
      The used language is C 
   */
   ml2_bib_startup(LANGUAGE_C); 

	osx = "\\sorcus\\ml2\\osx\\ml2-*.*";
	/* In Windows NT some Parameters of the board like I/O address and
	   interrupt channel are retained by the registry. Therefore some
		parameters of 'ml2_reset' are not used */
   retval = ml2_reset( 0, 						// card number
                  0x380, 					// not used in Windows NT
                  0, 						// mode: no interrupts used
                  7, 						// not used in Windows NT
                  1, 						// not used in Windows NT
                  * errorhandler, 		// address of error handler called
													//	back by the library
                  osx, 					   // operating system for the board
                  20);						// timeout


   if (retval>0)                       // if an error occured
   {
	   printf("\nError in 'ml2_reset': \n");
		errorclass = (byte)(retval>>8);
		errorcode  = (byte)(retval);
													// get the error message
      ml2_get_error_msg(errorstr, errorclass, errorcode);		 
      printf("Fehlerklasse: %02Xh\n",errorclass);
      printf("Fehlercode  : %02Xh\n",errorcode);
      printf("** %s **\n",errorstr);
	   ml2_exit();
  	   getch();
      return;
   }

	/*----------- internal LED blinking -------------*/
   printf("\nInternal LED:  ");
   for (w=0; w<BLINK_COUNT; w++)
   {
	   ml2_led_on();  	         
	   printf("*");

	   Sleep(MS_WAITING);
	   ml2_led_off(); 	 
	   Sleep(MS_WAITING);
   }
   printf("\n");


   ml2_exit();		           /* use ml2_exit to close the library */
	printf("\n\n<press any key>\n");
	getch();
   return;
}


/**********************************************************************
*  waitmillisec:
*     delays execution for a time given in milliseconds
**********************************************************************/
void waitmillisec(unsigned long msec)	
{
	unsigned long	start, current;

	start = GetTickCount();

	do {
	   current = GetTickCount();
	} while ( (current-start) <msec);
}

/********************************************************************
*  errorhandler: 
*     This is a callback function. It is called if there's an error
*     in the library. 
*********************************************************************/
void errorhandler(void)
{
   byte   errstr[80];
	struct ml2_error_info_type  err;

	ml2_get_error_info( &err);

   printf("\n\n\n************************************************\n");
   printf("************** ERROR OCCURED!!! ****************\n");
   printf("************************************************\n\n");
	switch (err.errortype) {
      case ERROR_DLL:
	         ml2_get_error_msg(errstr, err.dll.errorclass,
	                  err.dll.errorcode);
	         printf("DLL-Error    : %s\n", errstr);
	         printf("errorclass   : %02Xh\n", err.dll.errorclass);
	         printf("errorcode    : %02Xh\n", err.dll.errorcode);
            break;
      case ERROR_COMMUNICATION:
	         ml2_get_error_msg(errstr, err.dll.errorclass,
	                  err.dll.errorcode);
	         printf("Communication Error: %s\n", errstr);
	         printf("errorclass   : %02Xh\n", err.com.errorclass);
	         printf("errorcode    : %02Xh\n", err.com.errorcode);
            break;
      case ERROR_SYSTEM:
	         printf("System Error: %d(d)\n", err.system.error);
            break;
      case ERROR_DRIVER:
	         printf("Driver Error: \n");
	         printf("expected data length: %d(d)\n", 
	                                       err.drv.dataoutsize);
	         printf("real data length: %d(d)\n", 
	                                       err.drv.retlength);
            break;
      default: printf("unknown error\n");
   }
	getch();
	exit(1);
}

