/************************************************************************
*
*                          ML2DEMO2.C
*
*           Shows the handling of a Multi-LAB/2 board from a PC
*           with Windows NT: a realtime program is loaded
*                                                                      
*					      version      : see history                  
*							creation 	 : 05.01.96
*							last change  : see history
*							author       : M.Hcker
*
* 		(c) by SORCUS Computer GmbH Heidelberg 1996
*************************************************************************/

/************************************************************************
*
*	description:
*       The realtime program M2P0300.EXE is loaded to the Multi-LAB/2
*       board. After starting the blink rate of the internal LED can 
*       be modified
*
*	software requirements:
*       To make an EXE-file you have to link NML2BIB.LIB and ML2ERRD.C.  
*		  To run the application the NMLXBIB.DLL must be in the actual
*       directory or in the systems path.
*       The realtime program M8P0307.EXE must be in the given directory.
*
*  hints:
*		- this program is tested with MSVC V.4.1 but it should run with
* 			  other compilers that make 32-bit-code	
*
*     - to compile this example you have to build a 'console application' 
*       because of the use of 'printf'.
*
*     - the operating system for the Multi-LAB/2 card (ML2-1x.xxR) 
*       must be in the given path (see variable 'osx'). If this file
*       is not found (at runtime) please change the path at  
*       definition of the 'osx'-variable.
*
*************************************************************************/

/************************************************************************
*  history:
*   	1.B. 04.08.96 (MIH):
*        - MSVC 4.1
*        - path of real time program changed 
*        - ml2_reset: changing OsX to ml2-*.*
*   	1.A. 05.01.95 (MIH):
*************************************************************************/

#include <conio.h>
#include <stdio.h>
#include <dos.h>
#include <stdlib.h>
#include <windows.h>

#include "ml2bib.h"

#define BLINK_MAX   3000					// maximal blink rate
#define BLINK_MIN   200 					// minimal blink rate
#define BLINK_STEP  100	   				// steps to switch blink rate
#define TASKNUMBER  50

void errorhandler(void);
void ModifyBlinkrate(void);
void SetBrLower(unsigned short *pBr);
void SetBrHigher(unsigned short *pBr);


void main(void)
{
	unsigned int	retval;
	char			   errorstr[80];
	char			   *osx;
	byte           errorclass, errorcode;


   printf("\n***********************************************************\n");
   printf("           DEMO2: loads a program on the board\n");
   printf("***********************************************************\n");

   /* ml2_bib_startup: this procedure must be called before all other
      ml2_xxx procedures because of library initialisation.
      The used language is C 
   */
   ml2_bib_startup(LANGUAGE_C); 

	osx = "\\sorcus\\ml2\\osx\\ml2-*.*";
	/* In Windows NT some Parameters of the board like I/O address and
	   interrupt channel are retained by the registry. Therefore some
		parameters of 'ml2_reset' are not used */
   retval = ml2_reset( 0, 					// card number
                  0x380, 					// not used in Windows NT
                  0, 						// mode: no interrupts used
                  7, 						// not used in Windows NT
                  1, 						// not used in Windows NT
                  * errorhandler, 		// address of error handler called
													//	back by the library
                  osx,  					// operating system for the board
                  20);						// timeout


   if (retval>0)                       // if an error occured
   {
	   printf("\nError in 'ml2_reset': \n");
		errorclass = (byte)(retval>>8);
		errorcode  = (byte)(retval);
      printf("Port: %02Xh\n", ml8_get_port_status());
													// get the error message
      ml2_get_error_msg(errorstr, errorclass, errorcode);		 
      printf("Fehlerklasse: %02Xh\n",errorclass);
      printf("Fehlercode  : %02Xh\n",errorcode);
      printf("** %s **\n",errorstr);
	   ml2_exit();
  	   getch();
      return;
   }

	/*----------  Loading the realtime program  -----------*/
	printf("\n ** loading the program **\n");
	retval = ml2_transfer_and_install( 
						"\\sorcus\\ml2\\rt\\bc\\beisp\\M2P0300.EXE", 		
                                       // name of program
						0, 						// dummy, must be set to zero
						TASKNUMBER,				// install program under this 
													//	task number
						0x300, 					// program number
						0, 						// interrupt, not used here
						0x980, 					// flags
						0);						// data size, not needed
	
	if (retval) {								// if error occured
	   printf("\nError in 'ml2_transfer_and_install': \n");
		errorclass = (byte)(retval>>8);
		errorcode  = (byte)(retval);
													// get the error message
      ml2_get_error_msg(errorstr, errorclass, errorcode);		 
      printf("%s\n",errorstr);
	   ml2_exit();
  	   getch();
      return;
	}

	ml2_wakeup_task(TASKNUMBER);			// start the task

	ModifyBlinkrate();

   ml2_exit();		           /* use ml2_exit to close the library */
   return;
}


/**********************************************************************
*  ModifyBlinkrate:
*     this procedure sets the parameter #1 which is the blinkrate
**********************************************************************/
void ModifyBlinkrate(void)	
{
	char ch = ' ';								// holds keyboard input
	unsigned short br;						// holds blink rate

	printf("\n\n  changing of blinking frequency:\n");
	printf("    <h>: higher frequency\n");
	printf("    <l>: lower frequency\n");
	printf("    <q>: quit program\n\n");

	/* read the actual value of the blink rate (parameter #1) */
	ml2_read_par_block( 	TASKNUMBER, 
								0,					// start parameter 
								sizeof(br),		// number of bytes to read
								&br);				// pointer to write bytes
	do {
		if (kbhit()) {
		   ch = getch();
			if (ch=='l') SetBrHigher(&br);
			if (ch=='h') SetBrLower (&br);
	      /*------- write the new parameter ----------*/
	      ml2_write_par_block( 
	      					TASKNUMBER, 
								1,					// start parameter 
								sizeof(br),		// number of bytes to write
								&br);				// pointer to read bytes
		}
	} while ( ch!='q');
}

/**********************************************************************
*  SetBrHigher:
*     increases a value between BLINK_MAX and BLINK_MIN by step
*     BLINK_STEP
**********************************************************************/
void SetBrHigher(unsigned short *pBr)
{
	*pBr= *pBr+ BLINK_STEP;					// increase Br if not >BLINK_MAX
	if (*pBr>BLINK_MAX) *pBr = BLINK_MAX;
}

/**********************************************************************
*  SetBrLower:
*     decreases a value between BLINK_MAX and BLINK_MIN by step
*     BLINK_STEP
**********************************************************************/
void SetBrLower(unsigned short *pBr)
{
	*pBr= *pBr- BLINK_STEP;					// decrease Br if not <BLINK_MIN
	if (*pBr<BLINK_MIN) *pBr = BLINK_MIN;
}


/********************************************************************
*  errorhandler: 
*     This is a callback function. It is called if there's an error
*     in the library. 
*********************************************************************/
void errorhandler(void)
{
   byte   errstr[80];
	struct ml2_error_info_type  err;

	ml2_get_error_info( &err);

   printf("\n\n\n************************************************\n");
   printf("************** ERROR OCCURED!!! ****************\n");
   printf("************************************************\n\n");
	switch (err.errortype) {
      case ERROR_DLL:
	         ml2_get_error_msg(errstr, err.dll.errorclass,
	                  err.dll.errorcode);
	         printf("DLL-Error    : %s\n", errstr);
	         printf("errorclass   : %02Xh\n", err.dll.errorclass);
	         printf("errorcode    : %02Xh\n", err.dll.errorcode);
            break;
      case ERROR_COMMUNICATION:
	         ml2_get_error_msg(errstr, err.dll.errorclass,
	                  err.dll.errorcode);
	         printf("Communication Error: %s\n", errstr);
	         printf("errorclass   : %02Xh\n", err.com.errorclass);
	         printf("errorcode    : %02Xh\n", err.com.errorcode);
            break;
      case ERROR_SYSTEM:
	         printf("System Error: %d(d)\n", err.system.error);
            break;
      case ERROR_DRIVER:
	         printf("Driver Error: \n");
	         printf("expected data length: %d(d)\n", 
	                                       err.drv.dataoutsize);
	         printf("real data length: %d(d)\n", 
	                                       err.drv.retlength);
            break;
      default: printf("unknown error\n");
   }
	getch();
	exit(1);
}

