/************************************************************************
*
*                          ML2DEMO3.C
*
*           Shows the handling of interrupts of a Multi-LAB/2 board
*           with Windows NT
*
*					      version      : see history
*							creation 	 : 05.01.96
*							last change  : see history
*							author       : M.Haecker
*
* 		(c) by SORCUS Computer GmbH Heidelberg 1996
*************************************************************************/

/************************************************************************
*  description:
*       This sample uses the RT-program M2P0307.EXE. It is loaded onto the
*       Multi-LAB/2 board, is configured and then started. It sends
*       interrupts to the PC which are monitored.
*
*	software requirements:
*       To make an EXE-file you have to link NML2BIB.LIB and ML2ERRD.C.
*		  To run the application the NMLXBIB.DLL must be in the actual
*       directory or in the systems path (\winnt35\system32)
*       The realtime program M2P0307.EXE must be in the given directory.
*
*  hints:
*		- this program is tested with MSVC V.4.1 but it should also run with
* 			  other compilers that make 32-bit-code
*
*     - to compile this example you have to build a 'console application'
*       because of the use of 'printf'.
*
*
*     - the operating system for the Multi-LAB/2 card (ML2-1x.xxR) 
*       must be in the given path (see variable 'osx'). If this file
*       is not found (at runtime) please change the path at  
*       definition of the 'osx'-variable.
*
*************************************************************************/

/************************************************************************
*  history:
*   	1.C. 04.08.96 (MIH):
*        - MSVC 4.1
*        - path of real time program changed 
*        - ml2_reset: changing OsX to ml2-*.*
*   	1.B. 26.01.96 (MIH):
*        - forcing alignment = 1 byte for struct 'parameter'
*   	1.A. 05.01.96 (MIH):
*        - creation of the file
*************************************************************************/

#include "windows.h"
#include "conio.h"
#include "stdio.h"
#include "dos.h"
#include "stdlib.h"
#include "string.h"
#include "ml2bib.h"

#define TRUE	1
#define FALSE	0

#define BLINKRATE  0x500     /* blinkrate for the RT-program M8P0307.EXE */
#define IRQCOUNT   16        /* number of blinking */

#define RTPROG  "\\sorcus\\ml2\\rt\\pascal\\beisp\\M2P0307.EXE"

void errorhandler(void);
void interrupt_service(void);

ushort	    irq_count= 0;	            /* counter for the interrupts */


void main(void)
{
   ushort	w;
   ushort	pgm,
	         task;
   char		s[80];
   char		*osx;
	byte     errorclass, errorcode;
	char	   errorstr[80];


   /* the RT-program M2P0307.EXE uses byte alignment; therefore the
      following struct must also use byte byte alignment */
   #pragma pack(push, SORCPACK, 1) 
   struct {
	   byte	status;		               /* state of the RT-program */
	   ushort	blink_rate;             /* blinkrate of the RT-program */
	   byte	led_status;	               /* state of the LED at beginning */
	   ushort	countdown;	            /* number of blinking:
                                          0 = no blinking, 0xFFFF = infinite */
	   byte	with_srq;	               /* send interrupt to PC */
	   ushort	srq_sign;	            /* request message */
	   byte	srq_pending;               /* used by RT-program */
   } parameter;
   #pragma pack(pop, SORCPACK)


   printf(" ***********************************************\n");
   printf("   Sample DEMO3.C (demonstrating PC-Interrupts)\n");
   printf(" ***********************************************\n\n");


   ml2_bib_startup(LANGUAGE_C);        /* language: C */
				                           /* initialisation of the library */

	osx = "\\sorcus\\ml2\\osx\\ml2-*.*";
   w = ml2_reset(0,                    // cardnumber
                 0,                    // not used by library
                 1,                    // mode: interrupt mode 
                 9,                    // not used by library
                 0,                    // not used by library
                 * errorhandler,       // procedure that is called when an
                                       // error occures
                 osx,                  // operating system for the board
                 10);                  // timeout (* 100 ms)

   if (w>0)                            // if w>0 then an error occured
   {
	   printf("\nError in 'ml2_reset': \n");
		errorclass = (byte)(w>>8);
		errorcode  = (byte)(w);
  	   											// get the error message
      ml2_get_error_msg(errorstr, errorclass, errorcode);		 
      printf("Fehlerklasse: %02Xh\n",errorclass);
      printf("Fehlercode  : %02Xh\n",errorcode);
      printf("** %s **\n",errorstr);
	   ml2_exit();
      exit(1);
   }

   printf("Versions:\n");
   ml2_get_os_version(s);              // get version of OsX
   printf("  OsX Version:    %s\n", s);
   ml2_get_bib_version(s);             // get version of Nml2BIB.DLL
   printf("  DLL Version:    %s\n", s);
   ml2_get_drv_version(s);             // get version of MLX-Driver
   printf("  Driver Version: %s\n\n", s);


   ml2_set_service(interrupt_service); // set the interrupt service routine

   pgm = 0x0307;                       // number of the RT-program
   task = 16;                          // task number to install M8P0307.EXE

   w=ml2_transfer_and_install(RTPROG,  // program name
                              0,       // reserved
                              task,    // task number
                              pgm,     // program number
                              0,       // on-board-interrupt (not needed)
                              0x1980,  // flags: wakeup after install,
                                       //        NI-task
                              0);      // data area

   if (w>0)                            // if w>0 then an error occured
   {
    	printf("Error at ml2_transfer_and_install:\n");
      ml2_get_error_msg( s, (byte)(w>>8), (byte)(w&0xFF) );
      printf("Message: %s\nReturn value: %04X\n",s, w);
      ml2_exit();
      exit(1);
   }

   ml2_suspend_requests();             // don't allow interrupts now


   parameter.status     = 1;           // set parameter struct for RT-program
   parameter.blink_rate = BLINKRATE;
   parameter.led_status = 0;
   parameter.countdown  = IRQCOUNT;
   parameter.with_srq   = TRUE;
   parameter.srq_sign   = 0x0080;
   parameter.srq_pending= FALSE;

                                       // write parameters to board
   ml2_write_par_block(task, 0, sizeof(parameter), &parameter);

   printf("Receiving Interrupts\n\n");
   ml2_allow_requests();               // allow interrupts now
   do {
      //
      // Do anything until all interrupts are received
      //
   } while ( (!kbhit()) && (irq_count<IRQCOUNT));

   ml2_suspend_requests();             // suspend interrupts

   printf("\nInterrupts received: %d\n\n", irq_count);

   ml2_exit();

   printf("<press any key>");
	getch();
   return;
}

/***************************************************************************
*  Interrupt Service Routine
*     this procedure is called if an interrupt from MODULAR-4/486 board
*     was received
***************************************************************************/
void interrupt_service(void)
{
   ushort message;

   message = ml2_get_message();			// get the message sent by the board
   irq_count++;								// increment interrupz counter
   printf(" Interrupt: #%d; Message: %Xh\n", irq_count, message);
}


/********************************************************************
*  errorhandler:
*     This is a callback function. It is called if there's an error
*     in the library.
*********************************************************************/
void errorhandler(void)
{
   byte   errstr[80];
	struct ml2_error_info_type  err;

	ml2_get_error_info( &err);

   printf("\n\n\n************************************************\n");
   printf("************** ERROR OCCURED!!! ****************\n");
   printf("************************************************\n\n");
	switch (err.errortype) {
      case ERROR_DLL:
	         ml2_get_error_msg(errstr, err.dll.errorclass,
	                  err.dll.errorcode);
	         printf("DLL-Error    : %s\n", errstr);
	         printf("errorclass   : %02Xh\n", err.dll.errorclass);
	         printf("errorcode    : %02Xh\n", err.dll.errorcode);
            break;
      case ERROR_COMMUNICATION:
	         ml2_get_error_msg(errstr, err.dll.errorclass,
	                  err.dll.errorcode);
	         printf("Communication Error: %s\n", errstr);
	         printf("errorclass   : %02Xh\n", err.com.errorclass);
	         printf("errorcode    : %02Xh\n", err.com.errorcode);
            break;
      case ERROR_SYSTEM:
	         printf("System Error: %d(d)\n", err.system.error);
            break;
      case ERROR_DRIVER:
	         printf("Driver Error: \n");
	         printf("expected data length: %d(d)\n", 
	                                       err.drv.dataoutsize);
	         printf("real data length: %d(d)\n", 
	                                       err.drv.retlength);
            break;
      default: printf("unknown error\n");
   }
	getch();
	exit(1);
}

