/************************************************************************
*
*                          ML2_TWO.C
*
*           Shows the handling of interrupts of two Multi-LAB/2 boards
*           with Windows NT
*
*					      version      : see history
*							creation 	 : 12.12.96
*							last change  : see history
*							author       : M.Haecker
*
* 		(c) by SORCUS Computer GmbH Heidelberg 1996
*************************************************************************/

/************************************************************************
*  description:
*       This sample uses the RT-program M2P0307.EXE. It is loaded onto the
*       two Multi-LAB/2 boards and receives interrupts from both.
*
*	software requirements:
*       To make an EXE-file you have to link NML2BIB.LIB and ML2ERR.C.
*		  To run the application the NML2BIB.DLL must be in the actual
*       directory or in the systems path (\winnt35\system32)
*       The realtime program M2P0307.EXE must be in the given directory.
*
*	hardware requirements:
*	     Two Multi-LAB/2 boards must be installed in the system
*
*  hints:
*		- this program is tested with MSVC V.4.2 but it should also run with
* 			  other compilers that make 32-bit-code
*
*     - to compile this example you have to build a 'console application'
*       because of the use of 'printf'.
*
*     - Both boards use the same error handler and the same interrupt handler
*       but it is also possible to install specific handlers for both. 
*
*************************************************************************/

/************************************************************************
*  history:
*   	1.A. 12.12.96 (MIH):
*        - creation of the file
*************************************************************************/

#include "windows.h"
#include "conio.h"
#include "stdio.h"
#include "dos.h"
#include "stdlib.h"
#include "string.h"
#include "ml2bib.h"

#define TRUE	1
#define FALSE	0

#define BLINKRATE  0x100     /* blinkrate for the RT-program M2P0307.EXE */
#define IRQCOUNT   100       /* number of SRQs */

#define RTPROG  "c:\\sorcus\\ml2\\rt\\pascal\\beisp\\M2P0307.EXE"
#define OS      "c:\\sorcus\\ml2\\osx\\ml2-*.*"

void errorhandler(void);
void interrupt_service(void);

ushort	    irq_count= 0;	            /* counter for the interrupts */



/************************************************************************
*  reset of a card, loading/activating the operating system
*************************************************************************/
void ResetCard(ushort CardNr)
{
   ushort	w;
   char		s[80];

   printf("************ RESET CARD #%d ****************\n", CardNr);
   // ml2_reset automatically selects the card 'CardNr'
   w = ml2_reset(CardNr,               // card number
                 0,                    // ignored
                 1,                    // mode: with interrupts
                 0,
                 0,
                 * errorhandler,       // procedure that is called when an
                                       // error occures
                 OS,                   // operating system for the board
                 20);                  // timeout (* 100 ms)

   if (w>0)                            // if w>0 then an error occured
   {
	   printf("Error at ml2_reset:\n");
      ml2_get_error_msg( s, (byte)(w>>8), (byte)(w&0xFF) );
      printf("Message: %s\nReturn value: %04X\n",s, w);
      ml2_exit();
      getch();
      exit(1);
   }

   printf("Versions:\n");
   ml2_get_os_version(s);              // get version of OsX
   printf("  OsX Version:    %s\n", s);
   ml2_get_bib_version(s);             // get version of NML2BIB.DLL
   printf("  DLL Version:    %s\n", s);
   ml2_get_drv_version(s);             // get version of MLX-Driver
   printf("  Driver Version: %s\n\n", s);
}


/************************************************************************
*  installation of a realtime program on the board
*************************************************************************/
void InstallProgram(ushort CardNr)
{
   ushort	w;
   ushort	pgm,
	         task;
   char		s[80];

   /* the RT-program M2P0307.EXE uses byte alignment; therefore the
      following struct must also use byte byte alignment */
   #pragma pack(push, SORCPACK, 1) 
   struct {
	   byte	status;		               /* state of the RT-program */
	   ushort	blink_rate;             /* blinkrate of the RT-program */
	   byte	led_status;	               /* state of the LED at beginning */
	   ushort	countdown;	            /* number of blinking:
                                          0 = no blinking, 0xFFFF = infinite */
	   byte	with_srq;	               /* send interrupt to PC */
	   ushort	srq_sign;	            /* request message */
	   byte	srq_pending;               /* used by RT-program */
   } parameter;
   #pragma pack(pop, SORCPACK)

   
   printf("************ INSTALL FOR CARD #%d ****************\n", CardNr);
   /* select a card for installing the program */
   ml2_select_card(CardNr);

   ml2_set_service(interrupt_service); // set the interrupt service routine

   pgm = 0x0307;                       // number of the RT-program
   task = 16;                          // task number to install M2P0307.EXE

   w=ml2_transfer_and_install(RTPROG,  // program name
                              0,       // reserved
                              task,    // task number
                              pgm,     // program number
                              0,       // on-board-interrupt (not needed)
                              0x1980,  // flags: wakeup after install,
                                       //        NI-task
                              0);      // data area

   if (w>0)                            // if w>0 then an error occured
   {
    	printf("Error at ml2_transfer_and_install:\n");
      ml2_get_error_msg( s, (byte)(w>>8), (byte)(w&0xFF) );
      printf("Message: %s\nReturn value: %04X\n",s, w);
      ml2_exit();
      getch();
      exit(1);
   } 

   ml2_suspend_requests();             // don't allow interrupts now


   parameter.status     = 1;           // set parameter struct for RT-program
   parameter.blink_rate = BLINKRATE;
   parameter.led_status = 0;
   parameter.countdown  = IRQCOUNT;
   parameter.with_srq   = TRUE;
   parameter.srq_sign   = 0x0180;
   parameter.srq_pending= FALSE;

                                       // write parameters to board
   ml2_write_par_block(task, 0, sizeof(parameter), &parameter);
}

/************************************************************************
*  start the realtime program on the board
*************************************************************************/
void StartProgram(ushort CardNr)
{
   ml2_select_card(CardNr);
   ml2_allow_requests();               // allow interrupts 
}

/************************************************************************
*  stop the realtime program on the board
*************************************************************************/
void StopProgram(ushort CardNr)
{
   ml2_select_card(CardNr);
   ml2_suspend_requests();             // suspend interrupts 
}


/************************************************************************
*  main
*************************************************************************/
void main(void)
{

   printf(" ***********************************************\n");
   printf("   Sample ML2_TWO.C (demonstrating PC-Interrupts)\n");
   printf(" ***********************************************\n\n");


   ml2_bib_startup(LANGUAGE_C);        /* language: C */
				                           /* initialisation of the library */

   ResetCard(0);
   ResetCard(1);

   InstallProgram(0);
   InstallProgram(1);

   StartProgram(0);
   StartProgram(1);


   printf("********** Receiving Interrupts ***************\n\n");

   do {
      Sleep(1);
      //
      // Do anything until all interrupts are received
      //
   } while ( (!kbhit()) && (irq_count<IRQCOUNT*2) );

   StopProgram(0);
   StopProgram(1);
                     
   printf("\nInterrupts received: %d\n\n", irq_count);

   ml2_exit();

   printf("<press any key>");
	getch();
   return;
}

/***************************************************************************
*  Interrupt Service Routine
*     this procedure is called if an interrupt from one of the 
*     Multi-LAB/2 boards was received
***************************************************************************/
void interrupt_service(void)
{
   ushort Message;
   ushort ActualCard;

   ActualCard=ml2_get_selected_card(); // get the card that interrupted
   Message = ml2_get_message();			// get the message sent by the board
   irq_count++;								// increment interrupt counter
   printf(" Interrupt: #%3d; Message: %04Xh; Card #%d\n", 
                              irq_count, Message, ActualCard);
}


/********************************************************************
*  errorhandler:
*     This function is called if an error occures with one
*     of the Multi-LAB/2 boards
*********************************************************************/
void errorhandler(void)
{
   byte   errstr[80];
	struct ml2_error_info_type  err;
   ushort ActualCard;

   ActualCard=ml2_get_selected_card(); 
	ml2_get_error_info( &err);

   printf("\n************************************************\n");
   printf("         ERROR OCCURED: CARD #%d\n", ActualCard);
   printf("************************************************\n\n");
	switch (err.errortype) {
      case ERROR_DLL:
	         ml2_get_error_msg(errstr, err.dll.errorclass,
	                  err.dll.errorcode);
	         printf("DLL-Error    : %s\n", errstr);
	         printf("errorclass   : %02Xh\n", err.dll.errorclass);
	         printf("errorcode    : %02Xh\n", err.dll.errorcode);
            break;
      case ERROR_COMMUNICATION:
	         ml2_get_error_msg(errstr, err.dll.errorclass,
	                  err.dll.errorcode);
	         printf("Communication Error: %s\n", errstr);
	         printf("errorclass   : %02Xh\n", err.com.errorclass);
	         printf("errorcode    : %02Xh\n", err.com.errorcode);
            break;
      case ERROR_SYSTEM:
	         printf("System Error: %d(d)\n", err.system.error);
            break;
      case ERROR_DRIVER:
	         printf("Driver Error: \n");
	         printf("expected data length: %d(d)\n", 
	                                       err.drv.dataoutsize);
	         printf("real data length: %d(d)\n", 
	                                       err.drv.retlength);
            break;
      default: printf("unknown error\n");
   }
	getch();
	exit(1);
}

