{****************************************************************************
*
*   SOURCE TO BUILD THE DELPHI LIBRARY FOR THE MULTI-LAB/2 DEVICE LIBRARY
*
*   OPERATING SYSTEMS: WINDOWS 95
*                      WINDOWS NT
*
*   (C) SORCUS COMPUTER GMBH 1997
*
****************************************************************************}

{****************************************************************************
*   HINTS:
*
*   -   TO BUILD THE LIBRARY FOR WINDOWS 95 YOU HAVE TO DEFINE _WIN_95_.
*
*   -   TO BUILD THE LIBRARY FOR WINDOWS NT YOU HAVE TO DEFINE _WIN_NT_.
*
*   -   THIS SOURCE FILE HAS TO BE STORED WITH NAME AS FOLLOWS:
*
*                      WINDOWS 95        WINDOWS NT
*       --------------------------------------------
*       ML2            FML2DEB.PAS       NML2DEB.PAS   
****************************************************************************}


{$IFDEF _WIN_95_}

UNIT FML2DEB;

INTERFACE
USES FML2BIB, FML2TYPE, SYSUTILS, WINPROCS;

{$ENDIF}


{$IFDEF _WIN_NT_}

UNIT NML2DEB;

INTERFACE
USES NML2BIB, NML2TYPE, SYSUTILS, WINPROCS;

{$ENDIF}

CONST

{***************************************************************************}
{**     Kanal-Resourcen der Multi-LAB/2
{***************************************************************************}

{*-------------------------------------------------------------------------*}
{**     Definition analoger Single-Ended Eingnge [ad_channel]
{*-------------------------------------------------------------------------*}
   ML2_ASE_IN0          = $1000; {* 1. Single-Ended Eingang, AIN-0 *}
   ML2_ASE_IN1          = $1001; {* 2. Single-Ended Eingang, AIN-1 *}
   ML2_ASE_IN2          = $1002; {* 3. Single-Ended Eingang, AIN-2 *}
   ML2_ASE_IN3          = $1003; {* 4. Single-Ended Eingang, AIN-3 *}
   ML2_ASE_IN4          = $1004; {* 5. Single-Ended Eingang, AIN-4 *}
   ML2_ASE_IN5          = $1005; {* 6. Single-Ended Eingang, AIN-5 *}
   ML2_ASE_IN6          = $1006; {* 7. Single-Ended Eingang, AIN-6 *}
   ML2_ASE_IN7          = $1007; {* 8. Single-Ended Eingang, AIN-7 *}
   ML2_ASE_IN8          = $1008; {* 9. Single-Ended Eingang, AIN-8 *}
   ML2_ASE_IN9          = $1009; {* 10. Single-Ended Eingang, AIN-9 *}
   ML2_ASE_IN10         = $100A; {* 11. Single-Ended Eingang, AIN-10 *}
   ML2_ASE_IN11         = $100B; {* 12. Single-Ended Eingang, AIN-11 *}
   ML2_ASE_IN12         = $100C; {* 13. Single-Ended Eingang, AIN-12 *}
   ML2_ASE_IN13         = $100D; {* 14. Single-Ended Eingang, AIN-13 *}
   ML2_ASE_IN14         = $100E; {* 15. Single-Ended Eingang, AIN-14 *}
   ML2_ASE_IN15         = $100F; {* 16. Single-Ended Eingang, AIN-15 *}
   ML2_AD_GNDM          = $1010; {* Ground am Eingang der Karte *}
   ML2_AD_GNDA          = $1011; {* Ground am Eingang des ADC *}
   ML2_AD_VREF          = $1012; {* 5 Volt Referenzspannung des Moduls *}
   ML2_AD_DA0           = $1013; {* Ist-Wert Ausgang AOUT-0 *}
   ML2_AD_DA1           = $1014; {* Ist-Wert Ausgang AOUT-1 *}
   ML2_AD_TMP_ADC       = $1015; {* Temperaturwert am ADC *}

{*-------------------------------------------------------------------------*}
{**     Definition analoger Differenzeingnge [ad_channel]
{*-------------------------------------------------------------------------*}
   ML2_ADIF_IN0         = $2000; {* 1. Differenzeingang, AIN-0 - AIN-8 *}
   ML2_ADIF_IN1         = $2001; {* 2. Differenzeingang, AIN-1 - AIN-9 *}
   ML2_ADIF_IN2         = $2002; {* 3. Differenzeingang, AIN-2 - AIN-10 *}
   ML2_ADIF_IN3         = $2003; {* 4. Differenzeingang, AIN-3 - AIN-11 *}
   ML2_ADIF_IN4         = $2004; {* 5. Differenzeingang, AIN-4 - AIN-12 *}
   ML2_ADIF_IN5         = $2005; {* 6. Differenzeingang, AIN-5 - AIN-13 *}
   ML2_ADIF_IN6         = $2006; {* 7. Differenzeingang, AIN-6 - AIN-14 *}
   ML2_ADIF_IN7         = $2007; {* 8. Differenzeingang, AIN-7 - AIN-15 *}

{*-------------------------------------------------------------------------*}
{**     Definition analoger Ausgnge [da_channel]
{*-------------------------------------------------------------------------*}
   ML2_DA_0              = $3000; {* 1. analoger Ausgang, AOUT-0 *}
   ML2_DA_1              = $3001; {* 2. analoger Ausgang, AOUT-1 *}

{*-------------------------------------------------------------------------*}
{**     Definition digitaler Eingnge [ip_channel]
{*-------------------------------------------------------------------------*}
   ML2_IP_0             = $4000; {* 1. digitaler Eingang, DIN-0 *}
   ML2_IP_1             = $4001; {* 2. digitaler Eingang, DIN-1 *}
   ML2_IP_2             = $4002; {* 3. digitaler Eingang, DIN-2 *}
   ML2_IP_3             = $4003; {* 4. digitaler Eingang, DIN-3 *}
   ML2_IP_4             = $4004; {* 5. digitaler Eingang, DIN-4 *}
   ML2_IP_5             = $4005; {* 6. digitaler Eingang, DIN-5 *}
   ML2_IP_6             = $4006; {* 7. digitaler Eingang, DIN-6 *}
   ML2_IP_7             = $4007; {* 8. digitaler Eingang, DIN-7 *}
   ML2_IP_8             = $4008; {* 9. digitaler Eingang, DIN-8 *}
   ML2_IP_9             = $4009; {* 10. digitaler Eingang, DIN-9 *}
   ML2_IP_10            = $400A; {* 11. digitaler Eingang, DIN-10 *}
   ML2_IP_11            = $400B; {* 12. digitaler Eingang, DIN-11 *}
   ML2_IP_12            = $400C; {* 13. digitaler Eingang, DIN-12 *}
   ML2_IP_13            = $400D; {* 14. digitaler Eingang, DIN-13 *}
   ML2_IP_14            = $400E; {* 15. digitaler Eingang, DIN-14 *}
   ML2_IP_15            = $400F; {* 16. digitaler Eingang, DIN-15 *}
   ML2_IP_ALL           = $4FFF; {* Alle digitalen Eingnge lesen *}

{*-------------------------------------------------------------------------*}
{**     Definition digitaler Ausgnge [op_channel]
{*-------------------------------------------------------------------------*}
   ML2_OP_0             = $5000; {* 1. digitaler Ausgang, DOUT-0 *}
   ML2_OP_1             = $5001; {* 2. digitaler Ausgang, DOUT-1 *}
   ML2_OP_2             = $5002; {* 3. digitaler Ausgang, DOUT-2 *}
   ML2_OP_3             = $5003; {* 4. digitaler Ausgang, DOUT-3 *}
   ML2_OP_4             = $5004; {* 5. digitaler Ausgang, DOUT-4 *}
   ML2_OP_5             = $5005; {* 6. digitaler Ausgang, DOUT-5 *}
   ML2_OP_6             = $5006; {* 7. digitaler Ausgang, DOUT-6 *}
   ML2_OP_7             = $5007; {* 8. digitaler Ausgang, DOUT-7 *}
   ML2_OP_ALL           = $5FFF; {* Alle digitaler Ausgnge setzen *}

{*-------------------------------------------------------------------------*}
{**     Definition der Interruptkanle [irq_channel]
{*-------------------------------------------------------------------------*}
   ML2_IRQ_CHANNEL_3    = $6003; {* Interrupt-Kanal 3 *}
   ML2_IRQ_CHANNEL_5    = $6005; {* Interrupt-Kanal 5 *}
   ML2_IRQ_CHANNEL_9    = $6009; {* Interrupt-Kanal 9 *}
   ML2_IRQ_CHANNEL_10   = $600A; {* Interrupt-Kanal 10 *}
   ML2_IRQ_CHANNEL_11   = $600B; {* Interrupt-Kanal 11 *}
   ML2_IRQ_CHANNEL_12   = $600C; {* Interrupt-Kanal 12 *}
   ML2_IRQ_CHANNEL_15   = $600F; {* Interrupt-Kanal 15 *}

{*-------------------------------------------------------------------------*}
{**     Definition der DMA-Kanle [dma_channel]
{*-------------------------------------------------------------------------*}
   ML2_DMA_CHANNEL_0    = $7000; {* DMA-Kanal 0 *}
   ML2_DMA_CHANNEL_1    = $7001; {* DMA-Kanal 1 *}
   ML2_DMA_CHANNEL_3    = $7003; {* DMA-Kanal 3 *}

{*-------------------------------------------------------------------------*}
{**     Definition der Ereignis-Kanle [events_channel]
{*-------------------------------------------------------------------------*}
   ML2_EVENTS_IP8               = $8000;        {* Ereignis-Kanal 0 *}
   ML2_EVENTS_IP9               = $8001;        {* Ereignis-Kanal 1 *}
   ML2_EVENTS_IP10              = $8002;        {* Ereignis-Kanal 2 *}
   ML2_EVENTS_IP11              = $8003;        {* Ereignis-Kanal 3 *}
   ML2_EVENTS_IP12              = $8004;        {* Ereignis-Kanal 4 *}
   ML2_EVENTS_IP13              = $8005;        {* Ereignis-Kanal 5 *}
   ML2_EVENTS_IP14              = $8006;        {* Ereignis-Kanal 6 *}
   ML2_EVENTS_IP15              = $8007;        {* Ereignis-Kanal 7 *}

{*-------------------------------------------------------------------------*}
{**     Definition der Frequenzmessungs-Kanle [frequency_channel]
{*-------------------------------------------------------------------------*}
   ML2_FREQUENCY_IP8    = $9000;        {* Frequenzmessungs-Kanal 0 *}
   ML2_FREQUENCY_IP9    = $9001;        {* Frequenzmessungs-Kanal 1 *}
   ML2_FREQUENCY_IP10   = $9002;        {* Frequenzmessungs-Kanal 2 *}
   ML2_FREQUENCY_IP11   = $9003;        {* Frequenzmessungs-Kanal 3 *}
   ML2_FREQUENCY_IP12   = $9004;        {* Frequenzmessungs-Kanal 4 *}
   ML2_FREQUENCY_IP13   = $9005;        {* Frequenzmessungs-Kanal 5 *}
   ML2_FREQUENCY_IP14   = $9006;        {* Frequenzmessungs-Kanal 6 *}
   ML2_FREQUENCY_IP15   = $9007;        {* Frequenzmessungs-Kanal 7 *}

{*-------------------------------------------------------------------------*}
{**     Definition der Pulsbreitenmessungs-Kanle [pulsewidth_channel]
{*-------------------------------------------------------------------------*}
   ML2_PULSEWIDTH_IP8   = $A000;        {* Pulsbreitenmessung-Kanal 0 *}
   ML2_PULSEWIDTH_IP9   = $A001;        {* Pulsbreitenmessung-Kanal 1 *}
   ML2_PULSEWIDTH_IP10  = $A002;        {* Pulsbreitenmessung-Kanal 2 *}
   ML2_PULSEWIDTH_IP11  = $A003;        {* Pulsbreitenmessung-Kanal 3 *}
   ML2_PULSEWIDTH_IP12  = $A004;        {* Pulsbreitenmessung-Kanal 4 *}
   ML2_PULSEWIDTH_IP13  = $A005;        {* Pulsbreitenmessung-Kanal 5 *}
   ML2_PULSEWIDTH_IP14  = $A006;        {* Pulsbreitenmessung-Kanal 6 *}
   ML2_PULSEWIDTH_IP15  = $A007;        {* Pulsbreitenmessung-Kanal 7 *}

{*-------------------------------------------------------------------------*}
{**     Definition der Periodenmessungs-Kanle [period_channel]
{*-------------------------------------------------------------------------*}
   ML2_PERIOD_IP8               = $B000;        {* Periodenmessung-Kanal 0 *}
   ML2_PERIOD_IP9               = $B001;        {* Periodenmessung-Kanal 1 *}
   ML2_PERIOD_IP10              = $B002;        {* Periodenmessung-Kanal 2 *}
   ML2_PERIOD_IP11              = $B003;        {* Periodenmessung-Kanal 3 *}
   ML2_PERIOD_IP12              = $B004;        {* Periodenmessung-Kanal 4 *}
   ML2_PERIOD_IP13              = $B005;        {* Periodenmessung-Kanal 5 *}
   ML2_PERIOD_IP14              = $B006;        {* Periodenmessung-Kanal 6 *}
   ML2_PERIOD_IP15              = $B007;        {* Periodenmessung-Kanal 7 *}


{***************************************************************************}
{**     Einstellungen (flags), die zustzlich zu der Kanal-Resource angegeben
{**     werden knnen.
{***************************************************************************}

{*-------------------------------------------------------------------------*}
{**     Definition von 'Autoinkrement' [increment]
{**     In der Betriebsart Autoinkrement wird der Eingangsmultiplexer
{**     automatisch nach einer Wandlung auf den nchsten Kanal eingestellt.
{**     Kann fr ML2_ASE_IN0 bis ML2_ASE_IN15 und fr ML2_ADIF_IN0 bis
{**     ML2_ADIF_IN8 verwendet werden.
{*-------------------------------------------------------------------------*}
   ML2_NON_AUTO_INCREMENT       = $0000; {* Autoinkrement wird nicht verwendet *}
   ML2_AUTO_INCREMENT           = $0001; {* Autoinkrement eingeschaltet *}

{*-------------------------------------------------------------------------*}
{**     Definition der Updatekonstante [update]
{**     Nach dem Beschreiben des DA Bausteins kann der Wert gepuffert oder
{**     in die Ausgangsregister bernommen werden. Diese Einstellung kann
{**     fr die analogen Ausgnge ML2_DA_0 und ML2_DA_1 verwendet werden.
{*-------------------------------------------------------------------------*}
   ML2_DA_NON_UPDATE            = $0000; {* Ausgang wird beim Beschreiben
					   gepuffert. *}
   ML2_DA_UPDATE                = $0001; {* Ausgang wird beim Beschreiben in
					   die Ausgangsregister bernommen. *}

{*-------------------------------------------------------------------------*}
{**     Definition der Spannungs Bereiche [voltage]
{*-------------------------------------------------------------------------*}
   ML2_UPP_625mV                = $0100; {* Unipolar von 0 bis 625 mV *}
   ML2_UPP_1_25V                = $0200; {* Unipolar von 0 bis 1,25 V *}
   ML2_UPP_2_5V                 = $0300; {* Unipolar von 0 bis 2,5 V *}
   ML2_UPP_5V                   = $0400; {* Unipolar von 0 bis 5 V *}
   ML2_UPP_10V                  = $0500; {* Unipolar von 0 bis 10 mV *}
   ML2_UPN_625mV                = $0600; {* Unipolar von 0 bis -625 mV *}
   ML2_UPN_1_25V                = $0700; {* Unipolar von 0 bis -1,25 V *}
   ML2_UPN_2_5V                 = $0800; {* Unipolar von 0 bis -2,5 V *}
   ML2_UPN_5V                   = $0900; {* Unipolar von 0 bis -5 V *}
   ML2_UPN_10V                  = $0A00; {* Unipolar von 0 bis -10 V *}
   ML2_BP_312_5mV               = $0B00; {* Bipolar +/- 312,5 mV *}
   ML2_BP_625mV                 = $0C00; {* Bipolar +/- 625 mV *}
   ML2_BP_1_25V                 = $0D00; {* Bipolar +/- 1,25 V *}
   ML2_BP_2_5V                  = $0E00; {* Bipolar +/- 2,5 V *}
   ML2_BP_5V                    = $0F00; {* Bipolar +/- 5 V *}
   ML2_BP_10V                   = $1000; {* Bipolar +/- 10 V *}
   ML2_BP_20V                   = $1100; {* Bipolar +/- 20 V *}

{*-------------------------------------------------------------------------*}
{**     Definition der Strom Bereiche [ampere]
{*-------------------------------------------------------------------------*}
   ML2_UP_0_TO_20mA              = $1200; {* Unipolar von 0 bis 20 mA *}
   ML2_UP_4_TO_20mA              = $1300; {* Unipolar von 4 bis 20 mA *}

{*-------------------------------------------------------------------------*}
{**     Definition der Latch-Konstante [latch]
{**     Wird dieses Flag angegeben, so werden vor dem Lesen der Eingnge
{**     ML2_IP_0 bis ML2_IP_15 und ML2_IP_ALL alle Eingnge gelatched.
{*-------------------------------------------------------------------------*}
   ML2_NON_LATCH                = $0000; {* Beim Lesen von dem Port wird kein
					    Latch-Befehl vorausgeschickt. *}
   ML2_SW_LATCH                 = $0001; {* Die Eingnge werden vor dem lesen
					    per Software gelatched *}
   ML2_HW_LATCH                 = $0002; {* Die Eingnge werden durch einen
					    externen Trigger gelatched
					    Nur fr ML2_IP_0 *}
   ML2_NON_HW_LATCH             = $0004; {* Das externe Triggern wird dadurch
					    wieder unterbunden *}

{*-------------------------------------------------------------------------*}
{**     Definition der externen Latch-Flanke [edge]
{**     Nur fr ML2_IP_0 einstellbar
{*-------------------------------------------------------------------------*}
   ML2_POS_EDGE                 = $0000; {* Positive Flanke *}
   ML2_NEG_EDGE                 = $0008; {* Negative Flanke *}

{*-------------------------------------------------------------------------*}
{**     Definition fr digitale Ausgnge freigeben [op_enable]
{**     Diese Einstellung gilt fr alle digitalen Ausgngen und kann
{**     daher nur mit der Kanal-Konstante ML2_OP_ALL kombiniert werden.
{*-------------------------------------------------------------------------*}
   ML2_OP_DISABLE               = $0001; {* Alle Ausgnge in den Tri-State
					   Zustand schalten *}
   ML2_OP_ENABLE                = $0002; {* Alle Ausgnge freigeben *}

{*-------------------------------------------------------------------------*}
{**     Definition der DMA-Richtung [dma_direction]
{*-------------------------------------------------------------------------*}
   ML2_DMA_ML2_PC               = $0000; {* DMA-Richtung ML2 -> PC *}
   ML2_DMA_PC_ML2               = $0008; {* DMA-Richtung PC -> ML2 *}

{*-------------------------------------------------------------------------*}
{**     Definition der Freigabe des DMA-Betriebs [dma_enable]
{*-------------------------------------------------------------------------*}
   ML2_DMA_DISABLE              = $0001; {* DMA-Kanal sperren *}
   ML2_DMA_ENABLE               = $0002; {* DMA-Kanal freigeben *}

{*-------------------------------------------------------------------------*}
{**     Definition der Hardwareverbindung Multi-LAB/2 <-> PC [dma_connect]
{*-------------------------------------------------------------------------*}
   ML2_DMA_DISCONNECT           = $0000; {* Physikalische Verbindung von
					    Multi-LAB/2 und PC trennen *}
   ML2_DMA_CONNECT              = $0004; {* Physikalische Verbindung von
					    Multi-LAB/2 und PC herstellen *}

{*-------------------------------------------------------------------------*}
{**     Definition der Freigabe des IRQ-Betriebs [irq_enable]
{*-------------------------------------------------------------------------*}
   ML2_IRQ_DISABLE              = $0001; {* IRQ-Kanal sperren *}
   ML2_IRQ_ENABLE               = $0002; {* IRQ-Kanal freigeben *}

{*-------------------------------------------------------------------------*}
{**     Definition der Hardwareverbindung Multi-LAB/2 <-> PC [irq_connect]
{*-------------------------------------------------------------------------*}
   ML2_IRQ_DISCONNECT           = $0000; {* Physikalische Verbindung von
					    Multi-LAB/2 und PC trennen *}
   ML2_IRQ_CONNECT              = $0004; {* Physikalische Verbindung von
					    Multi-LAB/2 und PC herstellen *}

{*-------------------------------------------------------------------------*}
{**     Definition des Counter-Reset [counter_reset]
{*-------------------------------------------------------------------------*}
   ML2_COUNTER_RESET    = $0010;        {* Beim ffnen wird der Zhler auf
					   Null gesetzt. *}

{*-------------------------------------------------------------------------*}
{**     Definition des Gate-Eingangs [gate_in]
{*-------------------------------------------------------------------------*}
   ML2_GATE_TIMER_A     = $0000;        {* Es wird die Torzeit vom Timer A
					   verwendet *}
   ML2_GATE_IP2         = $0020;        {* Die Torzeit wird extern vom
					   Eingang IP-2 vorgegebene. *}

{*-------------------------------------------------------------------------*}
{**     Definition Auto-Wait fr
{**             Frequenzmessung, Pulsbreitenmessung und Periodenmessung
{*-------------------------------------------------------------------------*}
   ML2_NON_AUTO_WAIT            = $0000;        {* Kein Auto-Wait fr Messungen *}
   ML2_AUTO_WAIT                = $0040;        {* Auto-Wait fr Messungen *}

{*-------------------------------------------------------------------------*}
{**     Definition der Interrupts im Interrupt-Controller
{*-------------------------------------------------------------------------*}
	ML2_IRQ_IP_0            = $01;  {* IP-0 *}
	ML2_IRQ_IP_2            = $02;  {* IP-2 *}
	ML2_IRQ_RBF             = $04;  {* RBF *}
	ML2_IRQ_TIMER_A         = $08;  {* Timer-A *}
	ML2_IRQ_TIMER_B_OVER    = $10;  {* Timer-B, Overflow bzw. Timer-Interrupts *}
	ML2_IRQ_TIMER_B         = $20;  {* Timer-B, Messung beendet bzw. Inkr. Douwn *}
					{* Counter Overflow *}
{***************************************************************************}
{**     Einstellungen (ch_flag), die durch die Funktionen
{**     ml2_change_channel_parameter und ml2_get_channel_parameter
{*      verarbeitet werden knnen
{***************************************************************************}
   ML2_CHANGE_ALL_FLAGS         = $FFFFFFFF;    {* Alle Flags *}
   ML2_CHANGE_AUTO_INCREMENT    = $80000001;    {* Maske fr Autoinkrement *}
   ML2_CHANGE_DA_UPDATE         = $80000001;    {* Maske fr DA Ausgangsregister bernommen. *}
   ML2_CHANGE_RANGE             = $8000FF00;    {* Maske fr Strom/Spannungsbereiche *}
   ML2_CHANGE_LATCH             = $80000007;    {* Maske fr latchen *}
   ML2_MASKE_EDGE               = $80000008;    {* Maske fr pos/neg Flanke *}
   ML2_CHANGE_OP_PORT           = $80000003;    {* Maske fr OP Alle Ausgnge freigeben/sperren *}
   ML2_CHANGE_DMA_DIRECTION     = $80000008;    {* Maske fr DMA-Richtung *}
   ML2_CHANGE_DMA_CONNECTION    = $80000004;    {* Maske fr Physikalische Verbindung Multi-LAB/2 und PC *}
   ML2_CHANGE_DMA_PORT          = $80000003;    {* Maske fr DMA-Kanal freigeben/sperren *}
   ML2_CHANGE_IRQ_DIRECTION     = $80000008;    {* Maske fr IRQ-Richtung *}
   ML2_CHANGE_IRQ_CONNECTION    = $80000004;    {* Maske fr Physikalische Verbindung Multi-LAB/2 und PC *}
   ML2_CHANGE_IRQ_PORT          = $80000003;    {* Maske fr IRQ-Kanal freigeben/sperren *}
   ML2_CHANGE_AUTO_WAIT         = $80000040;    {* Maske fr Auto-Wait fr Messungen *}


{$IFDEF _WIN_95_}
   DLLREFERENZ                   = 'FML2DEB.DLL';   
{$ENDIF}

{$IFDEF _WIN_NT_}
   DLLREFERENZ                   = 'NML2DEB.DLL';   
{$ENDIF}



TYPE 
    HML2 = WORD;


function ml2_open_channel
	(cardnumber, channel: WORD; flags: LONGINT;
	VAR error: WORD): HML2; 
	cdecl;

procedure ml2_close_channel(handle: HML2); 
	cdecl;

procedure ml2_set_data(handle: HML2; data: INTEGER); 
	cdecl;

function ml2_get_data(handle: HML2): INTEGER; 
	cdecl;

procedure ml2_change_channel_parameter(handle: HML2; ch_flag, flags: LONGINT); 
	cdecl;

function ml2_get_channel_parameter(handle: HML2; ch_flag: LONGINT): LONGINT;
	cdecl;

function ml2_get_device_state(handle: HML2): BYTE; 
	cdecl;

procedure ml2_set_correction(handle: HML2; gain, offset: WORD); 
	cdecl;

procedure ml2_get_correction(handle: HML2; VAR gain, offset: WORD); 
	cdecl;

procedure ml2_calculate_correction
	(handle: HML2; set_value_1, true_value_1, set_value_2, true_value_2: WORD);
	cdecl;

procedure ml2_set_settletime
	(handle: HML2; settletime: WORD);
	cdecl;

procedure ml2_get_settletime(handle: HML2; VAR settletime: WORD);
	cdecl;

procedure ml2_get_deb_version( VAR version: str80 );
	cdecl;


IMPLEMENTATION

function ml2_open_channel( cardnumber, channel: WORD; flags: LONGINT;
			   VAR error: WORD ): HML2;
    EXTERNAL DLLREFERENZ; 

procedure ml2_close_channel( handle: HML2 );
    EXTERNAL DLLREFERENZ; 

procedure ml2_set_data( handle: HML2; data: INTEGER );
    EXTERNAL DLLREFERENZ; 

function ml2_get_data( handle: HML2 ): INTEGER;
    EXTERNAL DLLREFERENZ; 

procedure ml2_change_channel_parameter( handle: HML2; ch_flag, flags: LONGINT );
    EXTERNAL DLLREFERENZ; 

function ml2_get_channel_parameter( handle: HML2; ch_flag: LONGINT ): LONGINT;
    EXTERNAL DLLREFERENZ; 

function ml2_get_device_state( handle: HML2 ): BYTE;
    EXTERNAL DLLREFERENZ; 

procedure ml2_set_correction( handle: HML2; gain, offset: WORD );
    EXTERNAL DLLREFERENZ; 

procedure ml2_get_correction( handle: HML2; VAR gain, offset: WORD );
    EXTERNAL DLLREFERENZ; 

procedure ml2_calculate_correction( handle: HML2; set_value_1,
		true_value_1, set_value_2, true_value_2: WORD );
    EXTERNAL DLLREFERENZ; 

procedure ml2_set_settletime( handle: HML2; settletime: WORD );
    EXTERNAL DLLREFERENZ; 

procedure ml2_get_settletime( handle: HML2; VAR settletime: WORD );
    EXTERNAL DLLREFERENZ; 

PROCEDURE Cml2_get_deb_version( version: PChar );
   EXTERNAL DLLREFERENZ NAME 'ml2_get_deb_version';

PROCEDURE ml2_get_deb_version( VAR version: str80 );
   var ver: array [0..80] of char;
begin
   Cml2_get_deb_version( ver);
   version:=StrPas(ver);
end;

END.

