{***********************************************************************

      MDDDEMO
      Borland Delphi 5.0 project

      PURPOSE
      Shows the handling of a Multi-LAB/2 board from a PC
      with Windows NT / Windows 95 and Borland Delphi 5.0

      NOTES
      This program runs for Multi-LAB/2d, /2i and /2h.
      For a Multi-LAB/2a the range of the analog input must be changed
      to cps.usRange := RANGE_BIP_5V before calling mdd2_open_channel(..).
      The board number is 0.
      This program must be copied into the NEW directory
      SORCUS\ML2\WINNT\DELPHI\SAMPLE.
      The DCUs MLXW32, MLXTYPE, MDDCPS, MLXERRE, MDDDIAGD must be in the
      directory SORCUS\ML2\WINNT\DELPHI\DELPHIx (x= 2, 3, 4 or 5) for the
      corresponding DELPHI-version.
      The Multi-LAB/2-Device-Driver must be in the directory SORCUS\ML2\MDD.
      The Multi-LAB/2-OsX must be in the directory SORCUS\ML2\OSX.
      An OsX version ml2-1E.00R or higher is required.

      AUTHOR
      JD

      STATUS
      This program was tested with DELPHI 5.0 and Windows NT 4.0.
      It should work also with other Delphi-Versions and Windows 95 or 98.

      VERSION
      See history

      COPYRIGHTS
      SORCUS Computer GmbH 1999
      All Rights Reserved

      DESCRIPTION:
      - Board number 0 can be reset
      - The local LEDs can be switched on and off.
      - The analog input AIN-0 can be read.
      - If an error occurs, the error handler shows a message box.

      HISTORY:
      25.10.1999 (JD):
      - creation of this file and the corresponding project.

***********************************************************************}

unit Unit1;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  MLXW32, MLXTYPE, MDDCPS, MLXERRE, MDDDIAGD, StdCtrls, ExtCtrls;

type
  TFormMain = class(TForm)
    ButtonResetBoard0: TButton;
    ButtonLedOn: TButton;
    ButtonLedOff: TButton;
    Read: TButton;
    AnalogInput0: TLabel;
    AINDisplay: TMemo;
    procedure ButtonResetBoard0Click(Sender: TObject);
    procedure ButtonLedOnClick(Sender: TObject);
    procedure ButtonLedOffClick(Sender: TObject);
    procedure ReadClick(Sender: TObject);
  private
    { Private-Deklarationen }
  public
    { Public-Deklarationen }
  end;

var
  FormMain: TFormMain;
  wTaskNo : WORD;               { Task number of the MDD }
  hLED, hAIN : HMDD2;          { MDD handles as globals  }

implementation

{$R *.DFM}

{**********************************************************
      MyErrorHandler

      Implementation of the error handler.
**********************************************************}
procedure MyErrorHandler; far;
VAR
   errorclass, errorcode : BYTE;
   errormsg, diagmsg : STRING;
   error    : word;
BEGIN
   ml2_get_error_class_and_code (errorclass, errorcode);
   mlx_get_error_msg(errormsg, errorclass, errorcode);
   if (errorclass = 5) then begin
      error := ml2_get_message;
      errormsg := errormsg + ', SRQ-Code ' + IntToHex(error, 2);
   end
   else begin
      if (errorclass = $B) and
         ((errorcode = $42) or (errorcode = $43)) then begin
         error := mdd2_get_diagnosis;
         mdd8_get_diagnosis_msg (diagmsg, error);
         errormsg := errormsg + ': ' + diagmsg;
      end;
   end;
   MessageDlg(errormsg, mtError, [mbYes], 0);
   ml2_clear();
END;

{**********************************************************
      ButtonResetBoard0Click

      Reset board 0 and open mdd channels.
**********************************************************}
procedure TFormMain.ButtonResetBoard0Click(Sender: TObject);
var
   strOsX  : str80;
   errormsg: STR80;
   wStatus : word;
   cps     : CPS_ML2;
begin
     ml2_bib_startup(LANGUAGE_PASCAL);

     {reset board 0}
     strOsX := '..\..\..\osx\ml2-*.*';
     wStatus := ml2_reset(0, 0, 1, 0, 0, @MyErrorHandler, strOsX, 300);
     if (wStatus <> 0) then begin
        errormsg := 'Error ' + IntToHex(wStatus, 4) + ' in reset';
        MessageDlg(errormsg, mtError, [mbYes], 0);
        ml8_exit;
        exit;
     end;

     {load mdd into card ram }
     wTaskNo := 1;
     wStatus := ml2_transfer_and_install ('..\..\..\mdd\ml2d0000.lib', 0, wTaskNo, $4FF, 0, $800, 0);
     if (wStatus <> 0) then begin
        errormsg := 'Error ' + IntToHex(wStatus, 4) + ' in transfer of mdd';
        MessageDlg(errormsg, mtError, [mbYes], 0);
        ml8_exit;
        exit;
     end;

     { open channel to led }
     cps.usDevice := DEVICE_LED;
     cps.usIndexFirst := 0;
     cps.usIndexLast := 0;
     hLED := mdd2_open_channel (wTaskNo, sizeof(cps), cps);
     if (hLED = 0) then begin
        errormsg := 'Error opening LED channel';
        MessageDlg(errormsg, mtError, [mbYes], 0);
        ml8_exit;
        exit;
     end;

     { open channel to analog input }
     cps.usDevice := DEVICE_AIN_SE;
     cps.usIndexFirst := 0;
     cps.usIndexLast := 0;
     cps.usReadMode := IO_MODE_DIRECT;
     cps.usRange := RANGE_BIP_10V;
     hAIN := mdd2_open_channel (wTaskNo, sizeof(cps), cps);
     if (hAIN = 0) then begin
        errormsg := 'Error opening AIN channel';
        MessageDlg(errormsg, mtError, [mbYes], 0);
        ml8_exit;
        exit;
     end;
end;


{**********************************************************
      ButtonLedOnClick

      Switch the local led on.
**********************************************************}
procedure TFormMain.ButtonLedOnClick(Sender: TObject);
begin
     mdd2_write_channel_byte(hLED, 1);
end;


{**********************************************************
      ButtonLedOffClick

      Switch the local led off
**********************************************************}
procedure TFormMain.ButtonLedOffClick(Sender: TObject);
begin
    mdd2_write_channel_byte(hLED, 0);
end;


{**********************************************************
      ReadClick

      Read analog input channel
**********************************************************}
procedure TFormMain.ReadClick(Sender: TObject);
var
    value  : SMALLINT;
    result : STRING;
    Voltage: DOUBLE;
    s      : PChar;
begin
    value := mdd2_read_channel_short(hAIN);
    Voltage := 20 * value / 4096;
    result := FormatFloat('0.00', Voltage) + ' V';
    s := PChar(result);
    AINDisplay.Lines.SetText(s);
end;

end.
